# Build Process
  - Run restore.py to run the script to reconcile the difference between local database and wallet.dat
  - First parameter should be path to addresses missed csv file
  - Second parameter should be rpc-user, Third parameter should be rpc-password'\
`` python3 restore.py /home/david/Desktop/node_1/lost_addr.csv bitcoin-rpc PaSS ``
